'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var reactHooks = require('@shopify/react-hooks');
var reactHtml = require('@shopify/react-html');
var reactI18n = require('@shopify/react-i18n');
var utilities = require('./utilities.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

/**
 * A self-serializing provider for `@shopify/i18n`'s I18nManager.
 * On the server it serializes its props to the DOM; on the client it retrieves the serialized props and rehydrates them.
 *
 * @param props an object containing the React children to render and any options to use when configuring the tree's `I18nManager`
 * @returns JSX wrapping the given children in an `<I18nContext.Provider>` and a `<Serialize />` component.
 */
function I18nUniversalProvider({
  children,
  ...explicitI18nDetails
}) {
  const [serialized, Serialize] = reactHtml.useSerialized('i18n');
  const i18nDetails = utilities.combinedI18nDetails(serialized, explicitI18nDetails);
  const manager = reactHooks.useLazyRef(() => new reactI18n.I18nManager(i18nDetails, serialized === null || serialized === void 0 ? void 0 : serialized.translations)).current;
  reactHtml.useHtmlAttributes({
    lang: i18nDetails.locale
  });
  const {
    onError,
    ...primitiveI18nDetails
  } = i18nDetails;
  return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(reactI18n.I18nContext.Provider, {
    value: manager
  }, children), /*#__PURE__*/React__default["default"].createElement(Serialize, {
    data: () => {
      const getData = () => ({
        translations: manager.extract(),
        ...primitiveI18nDetails
      });
      if (manager.loading) {
        return manager.resolve().then(getData);
      }
      return getData();
    }
  }));
}

exports.I18nUniversalProvider = I18nUniversalProvider;
